"""Auto-generated model profiles.

DO NOT EDIT THIS FILE MANUALLY.
This file is generated by the langchain-profiles CLI tool.

It contains data derived from the models.dev project.

Source: https://github.com/sst/models.dev
License: MIT License

To update these data, refer to the instructions here:

https://docs.langchain.com/oss/python/langchain/models#updating-or-overwriting-profile-data
"""

from typing import Any

_PROFILES: dict[str, dict[str, Any]] = {
    "anthropic/claude-3.5-haiku": {
        "name": "Claude Haiku 3.5",
        "release_date": "2024-10-22",
        "last_updated": "2024-10-22",
        "open_weights": False,
        "max_input_tokens": 200000,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "attachment": True,
        "temperature": True,
    },
    "anthropic/claude-3.7-sonnet": {
        "name": "Claude Sonnet 3.7",
        "release_date": "2025-02-19",
        "last_updated": "2025-02-19",
        "open_weights": False,
        "max_input_tokens": 200000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": True,
        "temperature": True,
    },
    "anthropic/claude-haiku-4.5": {
        "name": "Claude Haiku 4.5",
        "release_date": "2025-10-15",
        "last_updated": "2025-10-15",
        "open_weights": False,
        "max_input_tokens": 200000,
        "max_output_tokens": 64000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "anthropic/claude-opus-4": {
        "name": "Claude Opus 4",
        "release_date": "2025-05-22",
        "last_updated": "2025-05-22",
        "open_weights": False,
        "max_input_tokens": 200000,
        "max_output_tokens": 32000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": True,
        "temperature": True,
    },
    "anthropic/claude-opus-4.1": {
        "name": "Claude Opus 4.1",
        "release_date": "2025-08-05",
        "last_updated": "2025-08-05",
        "open_weights": False,
        "max_input_tokens": 200000,
        "max_output_tokens": 32000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "anthropic/claude-opus-4.5": {
        "name": "Claude Opus 4.5",
        "release_date": "2025-11-24",
        "last_updated": "2025-11-24",
        "open_weights": False,
        "max_input_tokens": 200000,
        "max_output_tokens": 32000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "anthropic/claude-opus-4.6": {
        "name": "Claude Opus 4.6",
        "release_date": "2026-02-05",
        "last_updated": "2026-02-05",
        "open_weights": False,
        "max_input_tokens": 1000000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "anthropic/claude-sonnet-4": {
        "name": "Claude Sonnet 4",
        "release_date": "2025-05-22",
        "last_updated": "2025-05-22",
        "open_weights": False,
        "max_input_tokens": 200000,
        "max_output_tokens": 64000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": True,
        "temperature": True,
    },
    "anthropic/claude-sonnet-4.5": {
        "name": "Claude Sonnet 4.5",
        "release_date": "2025-09-29",
        "last_updated": "2025-09-29",
        "open_weights": False,
        "max_input_tokens": 1000000,
        "max_output_tokens": 64000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "anthropic/claude-sonnet-4.6": {
        "name": "Claude Sonnet 4.6",
        "release_date": "2026-02-17",
        "last_updated": "2026-02-17",
        "open_weights": False,
        "max_input_tokens": 1000000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "arcee-ai/trinity-large-preview:free": {
        "name": "Trinity Large Preview",
        "release_date": "2026-01-28",
        "last_updated": "2026-01-28",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "arcee-ai/trinity-mini:free": {
        "name": "Trinity Mini",
        "release_date": "2026-01-28",
        "last_updated": "2026-01-28",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "black-forest-labs/flux.2-flex": {
        "name": "FLUX.2 Flex",
        "release_date": "2025-11-25",
        "last_updated": "2026-01-31",
        "open_weights": False,
        "max_input_tokens": 67344,
        "max_output_tokens": 67344,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "black-forest-labs/flux.2-klein-4b": {
        "name": "FLUX.2 Klein 4B",
        "release_date": "2026-01-14",
        "last_updated": "2026-01-31",
        "open_weights": True,
        "max_input_tokens": 40960,
        "max_output_tokens": 40960,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "black-forest-labs/flux.2-max": {
        "name": "FLUX.2 Max",
        "release_date": "2025-12-16",
        "last_updated": "2026-01-31",
        "open_weights": False,
        "max_input_tokens": 46864,
        "max_output_tokens": 46864,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "black-forest-labs/flux.2-pro": {
        "name": "FLUX.2 Pro",
        "release_date": "2025-11-25",
        "last_updated": "2026-01-31",
        "open_weights": False,
        "max_input_tokens": 46864,
        "max_output_tokens": 46864,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "bytedance-seed/seedream-4.5": {
        "name": "Seedream 4.5",
        "release_date": "2025-12-23",
        "last_updated": "2026-01-31",
        "open_weights": True,
        "max_input_tokens": 4096,
        "max_output_tokens": 4096,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "cognitivecomputations/dolphin-mistral-24b-venice-edition:free": {
        "name": "Uncensored (free)",
        "release_date": "2025-07-09",
        "last_updated": "2026-01-31",
        "open_weights": True,
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "deepseek/deepseek-chat-v3-0324": {
        "name": "DeepSeek V3 0324",
        "release_date": "2025-03-24",
        "last_updated": "2025-03-24",
        "open_weights": True,
        "max_input_tokens": 16384,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "deepseek/deepseek-chat-v3.1": {
        "name": "DeepSeek-V3.1",
        "release_date": "2025-08-21",
        "last_updated": "2025-08-21",
        "open_weights": True,
        "max_input_tokens": 163840,
        "max_output_tokens": 163840,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "deepseek/deepseek-r1-distill-llama-70b": {
        "name": "DeepSeek R1 Distill Llama 70B",
        "release_date": "2025-01-23",
        "last_updated": "2025-01-23",
        "open_weights": True,
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "deepseek/deepseek-v3.1-terminus": {
        "name": "DeepSeek V3.1 Terminus",
        "release_date": "2025-09-22",
        "last_updated": "2025-09-22",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "deepseek/deepseek-v3.1-terminus:exacto": {
        "name": "DeepSeek V3.1 Terminus (exacto)",
        "release_date": "2025-09-22",
        "last_updated": "2025-09-22",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "deepseek/deepseek-v3.2": {
        "name": "DeepSeek V3.2",
        "release_date": "2025-12-01",
        "last_updated": "2025-12-01",
        "open_weights": True,
        "max_input_tokens": 163840,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "deepseek/deepseek-v3.2-speciale": {
        "name": "DeepSeek V3.2 Speciale",
        "release_date": "2025-12-01",
        "last_updated": "2025-12-01",
        "open_weights": True,
        "max_input_tokens": 163840,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "google/gemini-2.0-flash-001": {
        "name": "Gemini 2.0 Flash",
        "release_date": "2024-12-11",
        "last_updated": "2024-12-11",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-2.5-flash": {
        "name": "Gemini 2.5 Flash",
        "release_date": "2025-07-17",
        "last_updated": "2025-07-17",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-2.5-flash-lite": {
        "name": "Gemini 2.5 Flash Lite",
        "release_date": "2025-06-17",
        "last_updated": "2025-06-17",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-2.5-flash-lite-preview-09-2025": {
        "name": "Gemini 2.5 Flash Lite Preview 09-25",
        "release_date": "2025-09-25",
        "last_updated": "2025-09-25",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-2.5-flash-preview-09-2025": {
        "name": "Gemini 2.5 Flash Preview 09-25",
        "release_date": "2025-09-25",
        "last_updated": "2025-09-25",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-2.5-pro": {
        "name": "Gemini 2.5 Pro",
        "release_date": "2025-03-20",
        "last_updated": "2025-06-05",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-2.5-pro-preview-05-06": {
        "name": "Gemini 2.5 Pro Preview 05-06",
        "release_date": "2025-05-06",
        "last_updated": "2025-05-06",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-2.5-pro-preview-06-05": {
        "name": "Gemini 2.5 Pro Preview 06-05",
        "release_date": "2025-06-05",
        "last_updated": "2025-06-05",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-3-flash-preview": {
        "name": "Gemini 3 Flash Preview",
        "release_date": "2025-12-17",
        "last_updated": "2025-12-17",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-3-pro-preview": {
        "name": "Gemini 3 Pro Preview",
        "release_date": "2025-11-18",
        "last_updated": "2025-11",
        "open_weights": False,
        "max_input_tokens": 1050000,
        "max_output_tokens": 66000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-3.1-flash-lite-preview": {
        "name": "Gemini 3.1 Flash Lite Preview",
        "release_date": "2026-03-03",
        "last_updated": "2026-03-03",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-3.1-pro-preview": {
        "name": "Gemini 3.1 Pro Preview",
        "release_date": "2026-02-19",
        "last_updated": "2026-02-19",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemini-3.1-pro-preview-customtools": {
        "name": "Gemini 3.1 Pro Preview Custom Tools",
        "release_date": "2026-02-19",
        "last_updated": "2026-02-19",
        "open_weights": False,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemma-2-9b-it": {
        "name": "Gemma 2 9B",
        "release_date": "2024-06-28",
        "last_updated": "2024-06-28",
        "open_weights": True,
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "google/gemma-3-12b-it": {
        "name": "Gemma 3 12B",
        "release_date": "2025-03-13",
        "last_updated": "2025-03-13",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemma-3-12b-it:free": {
        "name": "Gemma 3 12B (free)",
        "release_date": "2025-03-13",
        "last_updated": "2025-03-13",
        "open_weights": True,
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": True,
        "temperature": True,
    },
    "google/gemma-3-27b-it": {
        "name": "Gemma 3 27B",
        "release_date": "2025-03-12",
        "last_updated": "2025-03-12",
        "open_weights": True,
        "max_input_tokens": 96000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemma-3-27b-it:free": {
        "name": "Gemma 3 27B (free)",
        "release_date": "2025-03-12",
        "last_updated": "2025-03-12",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "attachment": True,
        "temperature": True,
    },
    "google/gemma-3-4b-it": {
        "name": "Gemma 3 4B",
        "release_date": "2025-03-13",
        "last_updated": "2025-03-13",
        "open_weights": True,
        "max_input_tokens": 96000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": True,
        "temperature": True,
    },
    "google/gemma-3-4b-it:free": {
        "name": "Gemma 3 4B (free)",
        "release_date": "2025-03-13",
        "last_updated": "2025-03-13",
        "open_weights": True,
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": True,
        "temperature": True,
    },
    "google/gemma-3n-e2b-it:free": {
        "name": "Gemma 3n 2B (free)",
        "release_date": "2025-07-09",
        "last_updated": "2025-07-09",
        "open_weights": True,
        "max_input_tokens": 8192,
        "max_output_tokens": 2000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": True,
        "temperature": True,
    },
    "google/gemma-3n-e4b-it": {
        "name": "Gemma 3n 4B",
        "release_date": "2025-05-20",
        "last_updated": "2025-05-20",
        "open_weights": True,
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": True,
        "temperature": True,
    },
    "google/gemma-3n-e4b-it:free": {
        "name": "Gemma 3n 4B (free)",
        "release_date": "2025-05-20",
        "last_updated": "2025-05-20",
        "open_weights": True,
        "max_input_tokens": 8192,
        "max_output_tokens": 2000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": True,
        "temperature": True,
    },
    "inception/mercury": {
        "name": "Mercury",
        "release_date": "2025-06-26",
        "last_updated": "2025-06-26",
        "open_weights": False,
        "max_input_tokens": 128000,
        "max_output_tokens": 32000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "inception/mercury-2": {
        "name": "Mercury 2",
        "release_date": "2026-03-04",
        "last_updated": "2026-03-04",
        "open_weights": False,
        "max_input_tokens": 128000,
        "max_output_tokens": 50000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "inception/mercury-coder": {
        "name": "Mercury Coder",
        "release_date": "2025-04-30",
        "last_updated": "2025-04-30",
        "open_weights": False,
        "max_input_tokens": 128000,
        "max_output_tokens": 32000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "liquid/lfm-2.5-1.2b-instruct:free": {
        "name": "LFM2.5-1.2B-Instruct (free)",
        "release_date": "2026-01-20",
        "last_updated": "2026-01-28",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "liquid/lfm-2.5-1.2b-thinking:free": {
        "name": "LFM2.5-1.2B-Thinking (free)",
        "release_date": "2026-01-20",
        "last_updated": "2026-01-28",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "meta-llama/llama-3.2-11b-vision-instruct": {
        "name": "Llama 3.2 11B Vision Instruct",
        "release_date": "2024-09-25",
        "last_updated": "2024-09-25",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": True,
        "temperature": True,
    },
    "meta-llama/llama-3.2-3b-instruct:free": {
        "name": "Llama 3.2 3B Instruct (free)",
        "release_date": "2024-09-25",
        "last_updated": "2024-09-25",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": True,
        "temperature": True,
    },
    "meta-llama/llama-3.3-70b-instruct:free": {
        "name": "Llama 3.3 70B Instruct (free)",
        "release_date": "2024-12-06",
        "last_updated": "2024-12-06",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "minimax/minimax-01": {
        "name": "MiniMax-01",
        "release_date": "2025-01-15",
        "last_updated": "2025-01-15",
        "open_weights": True,
        "max_input_tokens": 1000000,
        "max_output_tokens": 1000000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": True,
        "temperature": True,
    },
    "minimax/minimax-m1": {
        "name": "MiniMax M1",
        "release_date": "2025-06-17",
        "last_updated": "2025-06-17",
        "open_weights": True,
        "max_input_tokens": 1000000,
        "max_output_tokens": 40000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "minimax/minimax-m2": {
        "name": "MiniMax M2",
        "release_date": "2025-10-23",
        "last_updated": "2025-10-23",
        "open_weights": True,
        "max_input_tokens": 196600,
        "max_output_tokens": 118000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "minimax/minimax-m2.1": {
        "name": "MiniMax M2.1",
        "release_date": "2025-12-23",
        "last_updated": "2025-12-23",
        "open_weights": True,
        "max_input_tokens": 204800,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "minimax/minimax-m2.5": {
        "name": "MiniMax M2.5",
        "release_date": "2026-02-12",
        "last_updated": "2026-02-12",
        "open_weights": True,
        "max_input_tokens": 204800,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "minimax/minimax-m2.7": {
        "name": "MiniMax M2.7",
        "release_date": "2026-03-18",
        "last_updated": "2026-03-18",
        "open_weights": True,
        "max_input_tokens": 204800,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "mistralai/codestral-2508": {
        "name": "Codestral 2508",
        "release_date": "2025-08-01",
        "last_updated": "2025-08-01",
        "open_weights": True,
        "max_input_tokens": 256000,
        "max_output_tokens": 256000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "mistralai/devstral-2512": {
        "name": "Devstral 2 2512",
        "release_date": "2025-09-12",
        "last_updated": "2025-09-12",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "mistralai/devstral-medium-2507": {
        "name": "Devstral Medium",
        "release_date": "2025-07-10",
        "last_updated": "2025-07-10",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "mistralai/devstral-small-2505": {
        "name": "Devstral Small",
        "release_date": "2025-05-07",
        "last_updated": "2025-05-07",
        "open_weights": True,
        "max_input_tokens": 128000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "mistralai/devstral-small-2507": {
        "name": "Devstral Small 1.1",
        "release_date": "2025-07-10",
        "last_updated": "2025-07-10",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "mistralai/mistral-medium-3": {
        "name": "Mistral Medium 3",
        "release_date": "2025-05-07",
        "last_updated": "2025-05-07",
        "open_weights": False,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "mistralai/mistral-medium-3.1": {
        "name": "Mistral Medium 3.1",
        "release_date": "2025-08-12",
        "last_updated": "2025-08-12",
        "open_weights": False,
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "mistralai/mistral-small-3.1-24b-instruct": {
        "name": "Mistral Small 3.1 24B Instruct",
        "release_date": "2025-03-17",
        "last_updated": "2025-03-17",
        "open_weights": True,
        "max_input_tokens": 128000,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "mistralai/mistral-small-3.2-24b-instruct": {
        "name": "Mistral Small 3.2 24B Instruct",
        "release_date": "2025-06-20",
        "last_updated": "2025-06-20",
        "open_weights": True,
        "max_input_tokens": 96000,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "moonshotai/kimi-k2": {
        "name": "Kimi K2",
        "release_date": "2025-07-11",
        "last_updated": "2025-07-11",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "moonshotai/kimi-k2-0905": {
        "name": "Kimi K2 Instruct 0905",
        "release_date": "2025-09-05",
        "last_updated": "2025-09-05",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "moonshotai/kimi-k2-0905:exacto": {
        "name": "Kimi K2 Instruct 0905 (exacto)",
        "release_date": "2025-09-05",
        "last_updated": "2025-09-05",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "moonshotai/kimi-k2-thinking": {
        "name": "Kimi K2 Thinking",
        "release_date": "2025-11-06",
        "last_updated": "2025-11-06",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "moonshotai/kimi-k2.5": {
        "name": "Kimi K2.5",
        "release_date": "2026-01-27",
        "last_updated": "2026-01-27",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "moonshotai/kimi-k2:free": {
        "name": "Kimi K2 (free)",
        "release_date": "2025-07-11",
        "last_updated": "2025-07-11",
        "open_weights": True,
        "max_input_tokens": 32800,
        "max_output_tokens": 32800,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "nousresearch/hermes-3-llama-3.1-405b:free": {
        "name": "Hermes 3 405B Instruct (free)",
        "release_date": "2024-08-16",
        "last_updated": "2024-08-16",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "nousresearch/hermes-4-405b": {
        "name": "Hermes 4 405B",
        "release_date": "2025-08-25",
        "last_updated": "2025-08-25",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "nousresearch/hermes-4-70b": {
        "name": "Hermes 4 70B",
        "release_date": "2025-08-25",
        "last_updated": "2025-08-25",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "nvidia/nemotron-3-nano-30b-a3b:free": {
        "name": "Nemotron 3 Nano 30B A3B (free)",
        "release_date": "2025-12-14",
        "last_updated": "2026-01-31",
        "open_weights": True,
        "max_input_tokens": 256000,
        "max_output_tokens": 256000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "nvidia/nemotron-3-super-120b-a12b": {
        "name": "Nemotron 3 Super",
        "release_date": "2026-03-11",
        "last_updated": "2026-03-11",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "nvidia/nemotron-3-super-120b-a12b-free": {
        "name": "Nemotron 3 Super (free)",
        "release_date": "2026-03-11",
        "last_updated": "2026-03-11",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "nvidia/nemotron-nano-12b-v2-vl:free": {
        "name": "Nemotron Nano 12B 2 VL (free)",
        "release_date": "2025-10-28",
        "last_updated": "2026-01-31",
        "open_weights": True,
        "max_input_tokens": 128000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "nvidia/nemotron-nano-9b-v2": {
        "name": "nvidia-nemotron-nano-9b-v2",
        "release_date": "2025-08-18",
        "last_updated": "2025-08-18",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "nvidia/nemotron-nano-9b-v2:free": {
        "name": "Nemotron Nano 9B V2 (free)",
        "release_date": "2025-09-05",
        "last_updated": "2025-08-18",
        "open_weights": True,
        "max_input_tokens": 128000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "openai/gpt-4.1": {
        "name": "GPT-4.1",
        "release_date": "2025-04-14",
        "last_updated": "2025-04-14",
        "open_weights": False,
        "max_input_tokens": 1047576,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-4.1-mini": {
        "name": "GPT-4.1 Mini",
        "release_date": "2025-04-14",
        "last_updated": "2025-04-14",
        "open_weights": False,
        "max_input_tokens": 1047576,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-4o-mini": {
        "name": "GPT-4o-mini",
        "release_date": "2024-07-18",
        "last_updated": "2024-07-18",
        "open_weights": False,
        "max_input_tokens": 128000,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5": {
        "name": "GPT-5",
        "release_date": "2025-08-07",
        "last_updated": "2025-08-07",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5-chat": {
        "name": "GPT-5 Chat (latest)",
        "release_date": "2025-08-07",
        "last_updated": "2025-08-07",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5-codex": {
        "name": "GPT-5 Codex",
        "release_date": "2025-09-15",
        "last_updated": "2025-09-15",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5-image": {
        "name": "GPT-5 Image",
        "release_date": "2025-10-14",
        "last_updated": "2025-10-14",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5-mini": {
        "name": "GPT-5 Mini",
        "release_date": "2025-08-07",
        "last_updated": "2025-08-07",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5-nano": {
        "name": "GPT-5 Nano",
        "release_date": "2025-08-07",
        "last_updated": "2025-08-07",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5-pro": {
        "name": "GPT-5 Pro",
        "release_date": "2025-10-06",
        "last_updated": "2025-10-06",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 272000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": False,
    },
    "openai/gpt-5.1": {
        "name": "GPT-5.1",
        "release_date": "2025-11-13",
        "last_updated": "2025-11-13",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5.1-chat": {
        "name": "GPT-5.1 Chat",
        "release_date": "2025-11-13",
        "last_updated": "2025-11-13",
        "open_weights": False,
        "max_input_tokens": 128000,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5.1-codex": {
        "name": "GPT-5.1-Codex",
        "release_date": "2025-11-13",
        "last_updated": "2025-11-13",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5.1-codex-max": {
        "name": "GPT-5.1-Codex-Max",
        "release_date": "2025-11-13",
        "last_updated": "2025-11-13",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5.1-codex-mini": {
        "name": "GPT-5.1-Codex-Mini",
        "release_date": "2025-11-13",
        "last_updated": "2025-11-13",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 100000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5.2": {
        "name": "GPT-5.2",
        "release_date": "2025-12-11",
        "last_updated": "2025-12-11",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": False,
    },
    "openai/gpt-5.2-chat": {
        "name": "GPT-5.2 Chat",
        "release_date": "2025-12-11",
        "last_updated": "2025-12-11",
        "open_weights": False,
        "max_input_tokens": 128000,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": False,
    },
    "openai/gpt-5.2-codex": {
        "name": "GPT-5.2-Codex",
        "release_date": "2026-01-14",
        "last_updated": "2026-01-14",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5.2-pro": {
        "name": "GPT-5.2 Pro",
        "release_date": "2025-12-11",
        "last_updated": "2025-12-11",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": False,
    },
    "openai/gpt-5.3-codex": {
        "name": "GPT-5.3-Codex",
        "release_date": "2026-02-24",
        "last_updated": "2026-02-24",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": False,
    },
    "openai/gpt-5.4": {
        "name": "GPT-5.4",
        "release_date": "2026-03-05",
        "last_updated": "2026-03-05",
        "open_weights": False,
        "max_input_tokens": 1050000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": False,
    },
    "openai/gpt-5.4-mini": {
        "name": "GPT-5.4 Mini",
        "release_date": "2026-03-17",
        "last_updated": "2026-03-17",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5.4-nano": {
        "name": "GPT-5.4 Nano",
        "release_date": "2026-03-17",
        "last_updated": "2026-03-17",
        "open_weights": False,
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openai/gpt-5.4-pro": {
        "name": "GPT-5.4 Pro",
        "release_date": "2026-03-05",
        "last_updated": "2026-03-05",
        "open_weights": False,
        "max_input_tokens": 1050000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": False,
        "attachment": True,
        "temperature": False,
    },
    "openai/gpt-oss-120b": {
        "name": "GPT OSS 120B",
        "release_date": "2025-08-05",
        "last_updated": "2025-08-05",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "openai/gpt-oss-120b:exacto": {
        "name": "GPT OSS 120B (exacto)",
        "release_date": "2025-08-05",
        "last_updated": "2025-08-05",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "openai/gpt-oss-120b:free": {
        "name": "gpt-oss-120b (free)",
        "release_date": "2025-08-05",
        "last_updated": "2025-08-05",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "openai/gpt-oss-20b": {
        "name": "GPT OSS 20B",
        "release_date": "2025-08-05",
        "last_updated": "2025-08-05",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "openai/gpt-oss-20b:free": {
        "name": "gpt-oss-20b (free)",
        "release_date": "2025-08-05",
        "last_updated": "2026-01-31",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "openai/gpt-oss-safeguard-20b": {
        "name": "GPT OSS Safeguard 20B",
        "release_date": "2025-10-29",
        "last_updated": "2025-10-29",
        "open_weights": False,
        "max_input_tokens": 131072,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "openai/o4-mini": {
        "name": "o4 Mini",
        "release_date": "2025-04-16",
        "last_updated": "2025-04-16",
        "open_weights": False,
        "max_input_tokens": 200000,
        "max_output_tokens": 100000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "openrouter/free": {
        "name": "Free Models Router",
        "release_date": "2026-02-01",
        "last_updated": "2026-02-01",
        "open_weights": False,
        "max_input_tokens": 200000,
        "max_output_tokens": 8000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "prime-intellect/intellect-3": {
        "name": "Intellect 3",
        "release_date": "2025-01-15",
        "last_updated": "2025-01-15",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen-2.5-coder-32b-instruct": {
        "name": "Qwen2.5 Coder 32B Instruct",
        "release_date": "2024-11-11",
        "last_updated": "2024-11-11",
        "open_weights": True,
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen2.5-vl-72b-instruct": {
        "name": "Qwen2.5 VL 72B Instruct",
        "release_date": "2025-02-01",
        "last_updated": "2025-02-01",
        "open_weights": True,
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "qwen/qwen3-235b-a22b-07-25": {
        "name": "Qwen3 235B A22B Instruct 2507",
        "release_date": "2025-04-28",
        "last_updated": "2025-07-21",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-235b-a22b-thinking-2507": {
        "name": "Qwen3 235B A22B Thinking 2507",
        "release_date": "2025-07-25",
        "last_updated": "2025-07-25",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 81920,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-30b-a3b-instruct-2507": {
        "name": "Qwen3 30B A3B Instruct 2507",
        "release_date": "2025-07-29",
        "last_updated": "2025-07-29",
        "open_weights": True,
        "max_input_tokens": 262000,
        "max_output_tokens": 262000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-30b-a3b-thinking-2507": {
        "name": "Qwen3 30B A3B Thinking 2507",
        "release_date": "2025-07-29",
        "last_updated": "2025-07-29",
        "open_weights": True,
        "max_input_tokens": 262000,
        "max_output_tokens": 262000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-4b:free": {
        "name": "Qwen3 4B (free)",
        "release_date": "2025-04-30",
        "last_updated": "2025-07-23",
        "open_weights": True,
        "max_input_tokens": 40960,
        "max_output_tokens": 40960,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-coder": {
        "name": "Qwen3 Coder",
        "release_date": "2025-07-23",
        "last_updated": "2025-07-23",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 66536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-coder-30b-a3b-instruct": {
        "name": "Qwen3 Coder 30B A3B Instruct",
        "release_date": "2025-07-31",
        "last_updated": "2025-07-31",
        "open_weights": True,
        "max_input_tokens": 160000,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-coder-flash": {
        "name": "Qwen3 Coder Flash",
        "release_date": "2025-07-23",
        "last_updated": "2025-07-23",
        "open_weights": False,
        "max_input_tokens": 128000,
        "max_output_tokens": 66536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": False,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-coder:exacto": {
        "name": "Qwen3 Coder (exacto)",
        "release_date": "2025-07-23",
        "last_updated": "2025-07-23",
        "open_weights": True,
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-coder:free": {
        "name": "Qwen3 Coder 480B A35B Instruct (free)",
        "release_date": "2025-07-23",
        "last_updated": "2025-07-23",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 66536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-max": {
        "name": "Qwen3 Max",
        "release_date": "2025-09-05",
        "last_updated": "2025-09-05",
        "open_weights": False,
        "max_input_tokens": 262144,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-next-80b-a3b-instruct": {
        "name": "Qwen3 Next 80B A3B Instruct",
        "release_date": "2025-09-11",
        "last_updated": "2025-09-11",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-next-80b-a3b-instruct:free": {
        "name": "Qwen3 Next 80B A3B Instruct (free)",
        "release_date": "2025-09-11",
        "last_updated": "2025-09-11",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3-next-80b-a3b-thinking": {
        "name": "Qwen3 Next 80B A3B Thinking",
        "release_date": "2025-09-11",
        "last_updated": "2025-09-11",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "qwen/qwen3.5-397b-a17b": {
        "name": "Qwen3.5 397B A17B",
        "release_date": "2026-02-16",
        "last_updated": "2026-02-16",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "qwen/qwen3.5-plus-02-15": {
        "name": "Qwen3.5 Plus 2026-02-15",
        "release_date": "2026-02-16",
        "last_updated": "2026-02-16",
        "open_weights": False,
        "max_input_tokens": 1000000,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "sourceful/riverflow-v2-fast-preview": {
        "name": "Riverflow V2 Fast Preview",
        "release_date": "2025-12-08",
        "last_updated": "2026-01-28",
        "open_weights": True,
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "sourceful/riverflow-v2-max-preview": {
        "name": "Riverflow V2 Max Preview",
        "release_date": "2025-12-08",
        "last_updated": "2026-01-28",
        "open_weights": True,
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "sourceful/riverflow-v2-standard-preview": {
        "name": "Riverflow V2 Standard Preview",
        "release_date": "2025-12-08",
        "last_updated": "2026-01-28",
        "open_weights": True,
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "stepfun/step-3.5-flash": {
        "name": "Step 3.5 Flash",
        "release_date": "2026-01-29",
        "last_updated": "2026-01-29",
        "open_weights": True,
        "max_input_tokens": 256000,
        "max_output_tokens": 256000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "stepfun/step-3.5-flash:free": {
        "name": "Step 3.5 Flash (free)",
        "release_date": "2026-01-29",
        "last_updated": "2026-01-29",
        "open_weights": True,
        "max_input_tokens": 256000,
        "max_output_tokens": 256000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "x-ai/grok-3": {
        "name": "Grok 3",
        "release_date": "2025-02-17",
        "last_updated": "2025-02-17",
        "open_weights": False,
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "x-ai/grok-3-beta": {
        "name": "Grok 3 Beta",
        "release_date": "2025-02-17",
        "last_updated": "2025-02-17",
        "open_weights": False,
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "x-ai/grok-3-mini": {
        "name": "Grok 3 Mini",
        "release_date": "2025-02-17",
        "last_updated": "2025-02-17",
        "open_weights": False,
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "x-ai/grok-3-mini-beta": {
        "name": "Grok 3 Mini Beta",
        "release_date": "2025-02-17",
        "last_updated": "2025-02-17",
        "open_weights": False,
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": False,
        "temperature": True,
    },
    "x-ai/grok-4": {
        "name": "Grok 4",
        "release_date": "2025-07-09",
        "last_updated": "2025-07-09",
        "open_weights": False,
        "max_input_tokens": 256000,
        "max_output_tokens": 64000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "x-ai/grok-4-fast": {
        "name": "Grok 4 Fast",
        "release_date": "2025-08-19",
        "last_updated": "2025-08-19",
        "open_weights": False,
        "max_input_tokens": 2000000,
        "max_output_tokens": 30000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "x-ai/grok-4.1-fast": {
        "name": "Grok 4.1 Fast",
        "release_date": "2025-11-19",
        "last_updated": "2025-11-19",
        "open_weights": False,
        "max_input_tokens": 2000000,
        "max_output_tokens": 30000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "x-ai/grok-4.20-beta": {
        "name": "Grok 4.20 Beta",
        "status": "beta",
        "release_date": "2026-03-12",
        "last_updated": "2026-03-12",
        "open_weights": False,
        "max_input_tokens": 2000000,
        "max_output_tokens": 30000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "attachment": True,
        "temperature": True,
    },
    "x-ai/grok-4.20-multi-agent-beta": {
        "name": "Grok 4.20 Multi - Agent Beta",
        "status": "beta",
        "release_date": "2026-03-12",
        "last_updated": "2026-03-12",
        "open_weights": False,
        "max_input_tokens": 2000000,
        "max_output_tokens": 30000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
        "attachment": True,
        "temperature": True,
    },
    "x-ai/grok-code-fast-1": {
        "name": "Grok Code Fast 1",
        "release_date": "2025-08-26",
        "last_updated": "2025-08-26",
        "open_weights": False,
        "max_input_tokens": 256000,
        "max_output_tokens": 10000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "xiaomi/mimo-v2-flash": {
        "name": "MiMo-V2-Flash",
        "release_date": "2025-12-14",
        "last_updated": "2025-12-14",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "xiaomi/mimo-v2-omni": {
        "name": "MiMo-V2-Omni",
        "release_date": "2026-03-18",
        "last_updated": "2026-03-18",
        "open_weights": True,
        "max_input_tokens": 262144,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "xiaomi/mimo-v2-pro": {
        "name": "MiMo-V2-Pro",
        "release_date": "2026-03-18",
        "last_updated": "2026-03-18",
        "open_weights": True,
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "z-ai/glm-4.5": {
        "name": "GLM 4.5",
        "release_date": "2025-07-28",
        "last_updated": "2025-07-28",
        "open_weights": True,
        "max_input_tokens": 128000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "z-ai/glm-4.5-air": {
        "name": "GLM 4.5 Air",
        "release_date": "2025-07-28",
        "last_updated": "2025-07-28",
        "open_weights": True,
        "max_input_tokens": 128000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "z-ai/glm-4.5-air:free": {
        "name": "GLM 4.5 Air (free)",
        "release_date": "2025-07-28",
        "last_updated": "2025-07-28",
        "open_weights": True,
        "max_input_tokens": 128000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
        "attachment": False,
        "temperature": True,
    },
    "z-ai/glm-4.5v": {
        "name": "GLM 4.5V",
        "release_date": "2025-08-11",
        "last_updated": "2025-08-11",
        "open_weights": True,
        "max_input_tokens": 64000,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": True,
        "temperature": True,
    },
    "z-ai/glm-4.6": {
        "name": "GLM 4.6",
        "release_date": "2025-09-30",
        "last_updated": "2025-09-30",
        "open_weights": True,
        "max_input_tokens": 200000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "z-ai/glm-4.6:exacto": {
        "name": "GLM 4.6 (exacto)",
        "release_date": "2025-09-30",
        "last_updated": "2025-09-30",
        "open_weights": True,
        "max_input_tokens": 200000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "z-ai/glm-4.7": {
        "name": "GLM-4.7",
        "release_date": "2025-12-22",
        "last_updated": "2025-12-22",
        "open_weights": True,
        "max_input_tokens": 204800,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "z-ai/glm-4.7-flash": {
        "name": "GLM-4.7-Flash",
        "release_date": "2026-01-19",
        "last_updated": "2026-01-19",
        "open_weights": True,
        "max_input_tokens": 200000,
        "max_output_tokens": 65535,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
    "z-ai/glm-5": {
        "name": "GLM-5",
        "release_date": "2026-02-12",
        "last_updated": "2026-02-12",
        "open_weights": True,
        "max_input_tokens": 202752,
        "max_output_tokens": 131000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
        "attachment": False,
        "temperature": True,
    },
}



"""Standard unit tests for `ChatOpenRouter`."""

from langchain_tests.unit_tests import ChatModelUnitTests

from langchain_openrouter.chat_models import ChatOpenRouter

MODEL_NAME = "openai/gpt-4o-mini"


class TestChatOpenRouterUnit(ChatModelUnitTests):
    """Standard unit tests for `ChatOpenRouter` chat model."""

    @property
    def chat_model_class(self) -> type[ChatOpenRouter]:
        """Chat model class being tested."""
        return ChatOpenRouter

    @property
    def init_from_env_params(self) -> tuple[dict, dict, dict]:
        """Parameters to initialize from environment variables."""
        return (
            {
                "OPENROUTER_API_KEY": "api_key",
            },
            {
                "model": MODEL_NAME,
            },
            {
                "openrouter_api_key": "api_key",
            },
        )

    @property
    def chat_model_params(self) -> dict:
        """Parameters to create chat model instance for testing."""
        return {
            "model": MODEL_NAME,
            "api_key": "test-api-key",
        }

    @property
    def supports_image_inputs(self) -> bool:
        return True

    @property
    def supports_image_urls(self) -> bool:
        return True

    @property
    def supports_audio_inputs(self) -> bool:
        return True

    @property
    def supports_video_inputs(self) -> bool:
        return True

    @property
    def supports_pdf_inputs(self) -> bool:
        return True

    @property
    def model_override_value(self) -> str:
        return "openai/gpt-4o"
